@@ -1,17 +1,61 @@
-import datetime
-import uuid
-
-
-from foqus.aws_configuration import *
-from foqus.azure_configuration import *
-
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
+from foqus.cloud_configuration import *
 
+import datetime
+import uuid
 import calendar
 import codecs
 import smtplib
-import time
+
+
+# Sending emails
+def send_payment_email(customer_email):
+    first_name = db.get_profile(DATABASE_USERS_MANAGEMENT_TABLE_NAME, customer_email)[9]
+    logger.info("start sending email for informing_client_about_problem_shopify_payment  ...")
+    server = smtplib.SMTP(SMTP_HOST, 587)
+    server.login(SMTP_USERNAME, SMTP_PASSWORD)
+    fromaddr = "FOQUS <hello@foqus.ai>"
+    toaddr = customer_email
+    msg = MIMEMultipart()
+    msg['From'] = fromaddr
+    msg['To'] = toaddr
+    msg['Subject'] = 'Mettre à jour votre payement '
+    html_file = codecs.open(PATH_EMAIL_PROBLEM_SHOPIFY_PAYMENT, 'r')
+    payement_url = DOMAIN + 'payement/'
+    html = ((str(html_file.read()).replace("#first_name", first_name)).replace("#payement_url", payement_url))
+    part2 = MIMEText(html, 'html')
+    msg.attach(part2)
+    text = msg.as_string()
+    server.sendmail(fromaddr, toaddr, text)
+    logger.info("End of sending payment email to client %s" % customer_email)
+
+
+def send_inscription_email(customer_email, full_url, password=None):
+    try:
+        server = smtplib.SMTP(SMTP_HOST, 587)
+        server.starttls()
+        server.login(SMTP_USERNAME, SMTP_PASSWORD)
+        fromaddr = "FOQUS <contact@trynfit.com>"
+        toaddr = customer_email
+        msg = MIMEMultipart()
+        msg['From'] = fromaddr
+        msg['To'] = toaddr
+        msg['Subject'] = 'Activez votre compte FOQUS'
+        html_file = codecs.open(PATH_INSCRIPTION_EMAIL_CUSTOMER, 'r')
+        if password:
+            html = (str(html_file.read()).replace("#full_url", full_url).replace('#password', password))
+        else:
+            html = (str(html_file.read()).replace("#full_url", full_url))
+
+        part2 = MIMEText(html, 'html')
+        msg.attach(part2)
+        text = msg.as_string()
+        server.sendmail(fromaddr, toaddr, text)
+        server.quit()
+        logger.info("End of sending inscrition email for client %s" % customer_email)
+    except Exception as e:
+        logger.info("exception in sending email send_inscription_email ..." + str(e))
 
 
 def send_email_when_training_started(customer_name, project_name, api, subject):
@@ -40,17 +84,23 @@ def send_email_when_training_started(customer_name, project_name, api, subject):
             server.sendmail(fromaddr, toaddr, text)
             logger.info("End of sending email ")
         except Exception as e:
-            logger.info("exception in sending email ..." + str(e))
+            logger.info("exception in sending email send_email_when_training_started..." + str(e))
 
 
 def send_email_to_admin(subject, message):
+    '''
+       Sending to the admin an email with the error of the server
+       :param subject: the subject of the email (Error server)
+       :param message: the description of the error and where
+       :return:
+       '''
     try:
         if not LOCAL:
             logger.info("start sending email ...")
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
             fromaddr = "FOQUS <hello@foqus.ai>"
-            toaddr = "dbellarej@trynfit.com"
+            toaddr = ADMIN_EMAIL
             msg = MIMEMultipart()
             msg['From'] = fromaddr
             msg['To'] = toaddr
@@ -61,30 +111,7 @@ def send_email_to_admin(subject, message):
             server.sendmail(fromaddr, toaddr, text)
             logger.info("End of sending email to admin ")
     except Exception as e:
-        logger.info("exception in sending email to admin  ..." + str(e))
-
-
-def send_inscription_email(customer_email, full_url, password_client):
-
-    try:
-        logger.info("start sending inscription  email ...")
-        server = smtplib.SMTP(SMTP_HOST, 587)
-        server.login(SMTP_USERNAME, SMTP_PASSWORD)
-        fromaddr = "FOQUS <hello@foqus.ai>"
-        toaddr = customer_email
-        msg = MIMEMultipart()
-        msg['From'] = fromaddr
-        msg['To'] = toaddr
-        msg['Subject'] = 'Activate your account FOQUS'
-        html_file = codecs.open(PATH_INSCRIPTION_EMAIL_CUSTOMER, 'r')
-        html = (str(html_file.read()).replace("#full_url", full_url).replace("#password", password_client))
-        part2 = MIMEText(html, 'html')
-        msg.attach(part2)
-        text = msg.as_string()
-        server.sendmail(fromaddr, toaddr, text)
-        logger.info("End of sending inscrition email for client %s" % customer_email)
-    except Exception as e:
-        logger.info("exception in sending email ..." + str(e))
+        logger.info("exception in sending email to admin send_email_to_admin ..." + str(e))
 
 
 def send_email(customer_name, project_name, subject):
@@ -112,33 +139,97 @@ def send_email(customer_name, project_name, subject):
             server.sendmail(fromaddr, toaddr, text)
             logger.info("End of sending email ")
         except Exception as e:
-            logger.info("exception in sending email ..." + str(e))
+            logger.info("exception in sending email send_email..." + str(e))
 
 
-def send_email_training_started(email, project_name, customer_name, customer_type):
-    # Send Email
+def send_email_of_client_inscription(customer_email, date_inscription, subject):
+    '''
+    Sending to the admin an email with the subscribed user
+    :param customer_email: the new user email
+    :param date_inscription: the date of the user inscription
+    :param subject: the subject of the email (New sign up)
+    :return:
+    '''
+    try:
+        logger.info("start sending email of client inscription to admin ...")
+        server = smtplib.SMTP(SMTP_HOST, 587)
+        server.login(SMTP_USERNAME, SMTP_PASSWORD)
+        fromaddr = "FOQUS <hello@foqus.ai>"
+        toaddr = ADMIN_EMAIL
+        msg = MIMEMultipart()
+        msg['From'] = fromaddr
+        msg['To'] = toaddr
+        msg['Subject'] = subject
+        html_file = codecs.open(PATH_EMAIL_CLIENT_INSCRIPTION, 'r')
+        html = ((str(html_file.read()).replace("#email", customer_email))).replace("#date", date_inscription)
+        part2 = MIMEText(html, 'html')
+        msg.attach(part2)
+        text = msg.as_string()
+        server.sendmail(fromaddr, toaddr, text)
+        logger.info("End of sending email of client inscription to admin ")
+    except Exception as e:
+        logger.info("exception in sending email of client inscription ..." + str(e))
+
+
+def send_email_for_reset_password(customer_email, full_url, first_name_of_customer, mail_subject):
+
     server = smtplib.SMTP(SMTP_HOST, 587)
     server.login(SMTP_USERNAME, SMTP_PASSWORD)
     try:
         fromaddr = "FOQUS <hello@foqus.ai>"
         msg = MIMEMultipart()
-        msg['From'] = fromaddr
-        msg['To'] = email
-        msg['Subject'] = "Training completed"
-
-        html_file = codecs.open(PATH_EMAIL_TRINING_STARTED_CMS, 'r')
-        html = ((str(html_file.read()).replace("#name", customer_name)).replace("#type", customer_type)).replace(
-            "#project", project_name)
+        msg['From'] =fromaddr
+        msg['To'] = customer_email
+        msg['Subject'] = mail_subject
+        html_file = codecs.open(PATH_EMAIL_RESET_PASSWORD,'r')
+        html = ((str(html_file.read()).replace("#full_url", full_url)).replace("#first_name", first_name_of_customer))
         part2 = MIMEText(html, 'html')
         msg.attach(part2)
-        server.sendmail(fromaddr, email, msg.as_string())
+        server.sendmail(fromaddr, customer_email, msg.as_string())
+        return True
     except Exception as e:
-        logger.error("exception ......" + str(e))
+
+        logger.error("exception send_email_for_reset_password ......" + str(e))
+        return False
 
 
-def send_email_of_client_inscription(customer_name, date_inscription, subject):
+def send_email_for_activate_account(first_name, customer_email, full_url):
+    '''
+    :param first_name: the name of the client
+    :param customer_email: the email of the user that just inscripted
+    :param full_url: url of activation
+    :return:
+    '''
+    try:
+        logger.info("start sending email for account activation ...")
+        server = smtplib.SMTP(SMTP_HOST, 587)
+        server.login(SMTP_USERNAME, SMTP_PASSWORD)
+        fromaddr = "FOQUS <hello@foqus.ai>"
+        toaddr = customer_email
+        msg = MIMEMultipart()
+        msg['From'] = fromaddr
+        msg['To'] = toaddr
+        msg['Subject'] = 'Activate your account FOQUS'
+        html_file = codecs.open(PATH_EMAIL_ACTIVATE_ACCOUNT, 'r')
+        html = ((str(html_file.read()).replace("#full_url", full_url)).replace("#first_name", first_name))
+        part2 = MIMEText(html, 'html')
+        msg.attach(part2)
+        text = msg.as_string()
+        server.sendmail(fromaddr, toaddr, text)
+        logger.info("End of sending inscription email to client %s" % customer_email)
+    except Exception as e:
+        logger.info("exception in send_email_for_activate_account ..." + str(e))
+
+
+def send_email_to_client(customer_name, subject, message):
+    '''
+    :param customer_name: the customer name that will receive the email
+    :param subject: the subject of the email
+    :param message: depends on the erros that encountred when processing the shopify traning cron either no products in
+    store or the number of products passes the limit of his plan
+    :return: No return
+    '''
     customer_profile = db.get_customer_info_from_customer_name(customer_name=customer_name)
-
     for custmer in customer_profile:
         customer_email = custmer[3]
         try:
@@ -146,20 +237,20 @@ def send_email_of_client_inscription(customer_name, date_inscription, subject):
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
             fromaddr = "FOQUS <hello@foqus.ai>"
-            toaddr = ADMIN_EMAIL
+            toaddr = customer_email
             msg = MIMEMultipart()
             msg['From'] = fromaddr
             msg['To'] = toaddr
             msg['Subject'] = subject
-            html_file = codecs.open(PATH_EMAIL_CLIENT_INSCRIPTION, 'r')
-            html = ((str(html_file.read()).replace("#email", customer_email))).replace("#date", date_inscription)
+            html_file = codecs.open(PATH_EMAIL_TO_CLIENT, 'r')
+            html = str(html_file.read()).replace("#message", message)
             part2 = MIMEText(html, 'html')
             msg.attach(part2)
             text = msg.as_string()
             server.sendmail(fromaddr, toaddr, text)
-            logger.info("End of sending email of client inscription to admin ")
+            logger.info("End of sending email to client  cron shopify")
         except Exception as e:
-            logger.info("exception in sending email of client inscription ..." + str(e))
+            logger.info("exception in sending email to client cron shopify ..." + str(e))
 
 
 def create_or_update_user_apikey(user='anonymous', period_in_hours=72):
@@ -167,6 +258,11 @@ def create_or_update_user_apikey(user='anonymous', period_in_hours=72):
     db.commit_db_changes()
 
 
+def update_customer_apikey(email):
+    apikey = db.update_customer_apikey(email=email, apikey=str(uuid.uuid4()))
+    return apikey
+
+
 def specified_project_status(customer_name, customer_type, project_name):
     result = db.get_status_project(table_name=STATUS_PROJECT_TABLE, customer=customer_name,
                                    customer_type=customer_type, api="similars", project=project_name)
@@ -233,7 +329,7 @@ def get_user_apikey(customer):
 
 def is_customer_registered(customer):
     try:
-        user_apikey = db.get_apikey_from_customer(customer=customer)[0]
+        db.get_apikey_from_customer(customer=customer)[0]
     except:
         logger.error("Customer '" + customer + "' not found.")
         return False
@@ -280,7 +376,9 @@ def scores_repartition_per_users(customer, customer_type):
                 if i == 7:
                     if "similars" in response_list[j][i]:
                         similars = json.loads(response_list[j][i])
-                        if int(similars["similars"][0]['score']) < 30:
+                        if similars['similars'] == []:
+                            continue
+                        elif int(similars["similars"][0]['score']) < 30:
                             nb_person_10_30 = nb_person_10_30 + response_list[j][9]
                         elif int(similars["similars"][0]['score']) > 30 and int(
                                 similars["similars"][0]['score']) < 50:
@@ -300,6 +398,7 @@ def scores_repartition_per_users(customer, customer_type):
     return nb_person_list
 
 
+
 def get_counter_of_last_four_months(customer, customer_type):
     today = datetime.date.today()
     first = today.replace(day=1)
@@ -341,7 +440,7 @@ def get_counter_of_last_four_months(customer, customer_type):
                 current_day_in_the_last_month = today.replace(day=28, month=int(last_date_in_last_month.strftime("%m")))
             else:
                 current_day_in_the_last_month = today.replace(day=last_month_day).replace(
-                month=int(last_date_in_last_month.strftime("%m")))
+                    month=int(last_date_in_last_month.strftime("%m")))
 
         except Exception as e:
             current_day_in_the_last_month = today.replace(month=int(last_date_in_last_month.strftime("%m"))).replace(day=last_month_day)
@@ -363,7 +462,6 @@ def get_counter_of_last_four_months(customer, customer_type):
     else:
         user_progress_requests = 100
 
-
     user_progress_requests_3_month = db.select_utilistation_par_mois(HISTORY_SEARCH_TABLE, customer, customer_type,
                                                                      last_lastMonth_year)
     user_progress_requests_4_month = db.select_utilistation_par_mois(HISTORY_SEARCH_TABLE, customer, customer_type,
@@ -393,53 +491,6 @@ def project_exist(customer_name, customer_type, api, project):
     return result
 
 
-
-
-
-def send_email_for_reset_password(customer_email,full_url,first_name_of_customer,mail_subject):
-
-    server = smtplib.SMTP(SMTP_HOST, 587)
-    server.login(SMTP_USERNAME, SMTP_PASSWORD)
-    try:
-        fromaddr = "FOQUS <hello@foqus.ai>"
-        msg = MIMEMultipart()
-        msg['From'] =fromaddr
-        msg['To'] = customer_email
-        msg['Subject'] = mail_subject
-        html_file = codecs.open(PATH_EMAIL_RESET_PASSWORD,'r')
-        html = ((str(html_file.read()).replace("#full_url", full_url)).replace("#first_name", first_name_of_customer))
-        part2 = MIMEText(html, 'html')
-        msg.attach(part2)
-        server.sendmail(fromaddr, customer_email, msg.as_string())
-        return True
-    except Exception as e:
-
-        logger.error("exception ......" + str(e))
-        return False
-
-def send_email_for_activate_account(first_name , customer_email, full_url):
-
-    try:
-        logger.info("start sending email for account activation ...")
-        server = smtplib.SMTP(SMTP_HOST, 587)
-        server.login(SMTP_USERNAME, SMTP_PASSWORD)
-        fromaddr = "FOQUS <hello@foqus.ai>"
-        toaddr = customer_email
-        msg = MIMEMultipart()
-        msg['From'] = fromaddr
-        msg['To'] = toaddr
-        msg['Subject'] = 'Activate your account FOQUS'
-        html_file = codecs.open(PATH_EMAIL_ACTIVATE_ACCOUNT, 'r')
-        html = ((str(html_file.read()).replace("#full_url", full_url)).replace("#first_name", first_name))
-        part2 = MIMEText(html, 'html')
-        msg.attach(part2)
-        text = msg.as_string()
-        server.sendmail(fromaddr, toaddr, text)
-        logger.info("End of sending inscription email to client %s" % customer_email)
-    except Exception as e:
-        logger.info("exception in sending email ..." + str(e))
-
-
 def number_request_by_week(customer, customer_type):
     today = datetime.date.today()
 
@@ -466,26 +517,11 @@ def number_request_by_week(customer, customer_type):
     return nbr_request_by_week
 
 
-def send_email_to_client(customer_name, subject, message):
-    customer_profile = db.get_customer_info_from_customer_name(customer_name=customer_name)
-    for custmer in customer_profile:
-        customer_email = custmer[3]
-        try:
-            logger.info("start sending email of client inscription to admin ...")
-            server = smtplib.SMTP(SMTP_HOST, 587)
-            server.login(SMTP_USERNAME, SMTP_PASSWORD)
-            fromaddr = "FOQUS <hello@foqus.ai>"
-            toaddr = ADMIN_EMAIL
-            msg = MIMEMultipart()
-            msg['From'] = fromaddr
-            msg['To'] = toaddr
-            msg['Subject'] = subject
-            html_file = codecs.open(PATH_EMAIL_TO_CLIENT, 'r')
-            html = str(html_file.read()).replace("#message", message)
-            part2 = MIMEText(html, 'html')
-            msg.attach(part2)
-            text = msg.as_string()
-            server.sendmail(fromaddr, toaddr, text)
-            logger.info("End of sending email to client  cron shopify")
-        except Exception as e:
-            logger.info("exception in sending email to client  cron shopify ..." + str(e))
\ No newline at end of file
+def get_photos(json_input, customer_name, customer_type):
+    photos = []
+    try:
+        for i in range(get_json_ads_number(json_input, customer_name, customer_type)):
+            photos = photos + get_json_ad_photos(json_input, customer_name, customer_type, i)
+    except Exception as e:
+        logger.error(e)
+    return photos
\ No newline at end of file
