@@ -44,7 +44,8 @@ def format_to_json_response(response):
 def rest_api_request(server, request_type, user_api_key, operation, customer_name, customer_type, customer_universe,
                      project_name, body, customer_email, customer_password, type_user, first_name, last_name,
                      phone_number, job, number_of_staff, plan, cms_if_exist, url_cms, new_email, new_password,
-                     new_password_verif, subject_of_email, message_email, month_num, ip, token_cms):
+                     new_password_verif, subject_of_email, message_email, month_num, ip, token_cms, boundingbox={}):
+
     try:
         # REST API tests
         s = requests.Session()
@@ -75,7 +76,8 @@ def rest_api_request(server, request_type, user_api_key, operation, customer_nam
                 'body': body,
                 'month_num': month_num,
                 'ip': ip,
-                'token_cms': token_cms
+                'token_cms': token_cms,
+                'boundingbox': boundingbox if boundingbox else {}
                 }
 
         url = server + "/api/" + operation
@@ -94,20 +96,21 @@ def rest_api_request(server, request_type, user_api_key, operation, customer_nam
         return make_response(jsonify({"response": "Bad request"}), 400)
 
 
-@timeit
-def get_similars_if_exist(user_apikey, customer_name, customer_type, project_name, body, ip):
-        rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                              mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
-        value = rpc_queue.call(headers={'user_apikey': user_apikey,
-                                        'operation': 'get_similars_if_exist',
-                                        'customer_name': customer_name,
-                                        'customer_type': customer_type,
-                                        'project_name': project_name,
-                                        'ip': ip
-                                        },
-                               message_body=body)
+# @timeit
+def get_similars_if_exist(user_apikey, customer_name, customer_type, project_name, body, ip, boundingbox):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'user_apikey': user_apikey,
+                                    'operation': 'get_similars_if_exist',
+                                    'customer_name': customer_name,
+                                    'customer_type': customer_type,
+                                    'project_name': project_name,
+                                    'ip': ip,
+                                    'boundingbox': str(boundingbox) if boundingbox else "{}"
+                                    },
+                           message_body=body)
 
-        return value.decode('utf-8')
+    return value.decode('utf-8')
 
 
 # api_authentication
@@ -207,60 +210,6 @@ def shopify_training(user_apikey, customer_name, customer_type, project_name, bo
     my_queue_json.publish(body)
 
 
-# Trainings and Classifications
-def text_training(user_apikey, customer_name, customer_type, customer_universe, body, project_name):
-    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                          mqueue_port=MESSAGE_QUEUE_PORT,
-                          mqueue_user=MESSAGE_QUEUE_USER,
-                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
-    value = rpc_queue.call(headers={'user_apikey': user_apikey,
-                                    'operation': 'text_training',
-                                    'customer_name': customer_name,
-                                    'customer_type': customer_type,
-                                    'project_name': project_name,
-                                    'customer_universe': customer_universe},
-                           message_body=body)
-    value = value.decode('utf-8')
-    return value
-
-
-def equilibrate_customer_training_samples(user_apikey, customer_name, customer_type, customer_universe, body):
-    my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                             mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
-                             mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
-                             headers={'user_apikey': user_apikey,
-                                      'operation': 'equilibrate_customer_training_samples',
-                                      'customer_name': customer_name,
-                                      'customer_type': customer_type,
-                                      'customer_universe': customer_universe})
-    my_queue_json.publish(body)
-
-
-def image_training(user_apikey, customer_name, customer_type, customer_universe):
-    my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                             mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
-                             mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
-                             headers={'user_apikey': user_apikey,
-                                      'operation': 'image_training',
-                                      'customer_name': customer_name,
-                                      'customer_type': customer_type,
-                                      'customer_universe': customer_universe})
-    my_queue_json.publish('')
-
-
-def predict_customer(user_apikey, customer_name, customer_type, customer_universe, body):
-    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
-    value = rpc_queue.call(headers={'user_apikey': user_apikey,
-                                    'operation': 'predict_customer',
-                                    'customer_name': customer_name,
-                                    'customer_universe': customer_universe,
-                                    'customer_type': customer_type},
-                           message_body=body)
-    value = value.decode('utf-8')
-    return value
-
-
 @timeit
 def predict_image(user_apikey, customer_name, customer_type, body, project_name):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
@@ -274,17 +223,6 @@ def predict_image(user_apikey, customer_name, customer_type, body, project_name)
     return value
 
 
-def detect_missing_images(user_apikey, customer_name, customer_type, project, body):
-    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
-    value = rpc_queue.call(headers={'user_apikey': user_apikey,
-                                    'operation': 'get_missed_images',
-                                    'customer_name': customer_name,
-                                    'project': project,
-                                    'customer_type': customer_type},
-                           message_body=str(body))
-    return value
-
 @timeit
 def get_historic(user_apikey, customer_name, customer_type, body, project_name, month_num):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
@@ -358,22 +296,6 @@ def update_user_apikey(customer_name, customer_type, body):
     return value
 
 
-# detection_error
-def detection_error_training(user_apikey, customer_name, customer_type, customer_universe, body):
-    my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                             mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
-                             mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
-                             headers={'user_apikey': user_apikey,
-                                      'operation': 'detection_error_training',
-                                      'customer_name': customer_name,
-                                      'customer_type': customer_type,
-                                      'customer_universe': customer_universe})
-    my_queue_json.publish(body)
-
-
-
-
-
 @timeit
 def get_specified_project_status(user_apikey, customer_name, customer_type, project_name, body):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
@@ -495,17 +417,6 @@ def get_details_trainings_for_admin(customer_name, customer_type, project_name):
     value = value.decode('utf-8')
     return value
 
-
-def all_historic_users_management_customer(body):
-    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                          mqueue_port=MESSAGE_QUEUE_PORT,
-                          mqueue_user=MESSAGE_QUEUE_USER,
-                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
-    value = rpc_queue.call(headers={'operation': 'all_historic_users_management_customer'}, message_body=body)
-    value = value.decode('utf-8')
-    return value
-
-
 # api_can_create_users
 def can_create_users(customer_email, body, type_user, type_new_user, email, password, entreprise, nom, prenom,
                      num_tel, domaine):
@@ -884,7 +795,7 @@ def manage_project(customer_name, customer_type, api, project_name, project_id,
     return value.decode("utf-8")
 
 @timeit
-def payment_client(customer_name, customer_type, user_apikey, email,  plan_name, tva, methode_payment, operation, payment_id,
+def payment_client(customer_name, customer_type, user_apikey, email,  plan_name, methode_payment, operation, payment_id,
                    payer_id, stripe_token):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
                           mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
@@ -894,7 +805,6 @@ def payment_client(customer_name, customer_type, user_apikey, email,  plan_name,
                'customer_email': email,
                'user_apikey': user_apikey,
                'plan_name': plan_name,
-               'tva': str(tva),
                'methode_payment': methode_payment,
                'payment_id': payment_id,
                'payer_id': payer_id,
@@ -921,7 +831,7 @@ def payment_shopify(customer_name, customer_type, user_apikey, email,  plan_name
 
 
 @timeit
-def payment_info_client(customer_name, customer_type, user_apikey, name,  address, zipcode, country, city,
+def payment_info_client(customer_name, customer_type, user_apikey, name,  address, zipcode, country, city, tva_number,
                                  operation):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
                           mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
@@ -933,7 +843,82 @@ def payment_info_client(customer_name, customer_type, user_apikey, name,  addres
                'address': address,
                'zipcode': zipcode,
                'country': country,
-               'city': city}
+               'city': city,
+               'tva_number': tva_number}
     value = rpc_queue.call(headers=headers,
                            message_body='')
+    return value.decode("utf-8")
+
+@timeit
+def payment_details_client(customer_name, customer_type, user_apikey, choosed_plan, operation):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    headers = {'operation': operation,
+               'customer_name': customer_name,
+               'customer_type': customer_type,
+               'choosed_plan': choosed_plan,
+               'user_apikey': user_apikey}
+    value = rpc_queue.call(headers=headers,
+                           message_body='')
+    return value.decode("utf-8")
+
+
+def get_client_training_parameters(customer_name, customer_type, training_type):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'customer_name': customer_name,
+                                    'customer_type': customer_type,
+                                    'training_type': training_type,
+                                    'operation': 'training_parameters_client'},
+                           message_body="")
+    value = value.decode('utf-8')
+    return value
+
+
+def update_client_training_parameters(customer_name, customer_type, training_type, parameters):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'customer_name': customer_name,
+                                    'customer_type': customer_type,
+                                    'training_type': training_type,
+                                    'parameters': parameters,
+                                    'operation': 'update_training_parameters_client'},
+                           message_body="")
+    value = value.decode('utf-8')
+    return value
+
+
+def all_historic_users_management_customer(body, customer_name=None, customer_type=None):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'all_historic_users_management_customer',
+                                    'customer_name': customer_name if customer_name else None,
+                                    'customer_type': customer_type if customer_type else None,
+                                    },
+                           message_body=body)
+    value = value.decode('utf-8')
+    return value
+
+@timeit
+def customer_info(data):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'get_customer',
+                                    'data': data},
+                           message_body='')
+
+    return value.decode("utf-8")
+
+
+@timeit
+def update_customer_apikey(customer_email, user_apikey):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'update_customer_apikey',
+                                    'customer_email': customer_email,
+                                    "user_apikey" :  user_apikey},
+                           message_body='')
+
     return value.decode("utf-8")
\ No newline at end of file
